pub struct LineMap { /* private fields */ }Expand description
Cached line start byte offsets for a source string.
line_starts[i] is the byte offset of the start of line i (0-indexed
for LSP). Always begins with 0.
Implementations
Sourceimpl LineMap
impl LineMap
pub fn new(source: &str) -> Self
Sourcepub fn line_count(&self) -> u32
pub fn line_count(&self) -> u32
Number of lines (always at least 1).
Sourcepub fn line_for_byte(&self, byte: u32) -> u32
pub fn line_for_byte(&self, byte: u32) -> u32
Get the 0-based line index containing byte.
Sourcepub fn line_start(&self, line: u32) -> u32
pub fn line_start(&self, line: u32) -> u32
Byte offset where the given 0-based line starts. Returns
source_len if line is past the end.